==> neo4j-kernel-4.1.1-sources.jar: org/neo4j/kernel/impl/transaction/log/files/LogFiles.java <==
/*
 * Copyright (c) 2002-2020 "Neo4j,"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.transaction.log.files;

import java.io.File;
import java.io.IOException;
import java.util.function.LongSupplier;

import org.neo4j.kernel.impl.transaction.log.PhysicalLogVersionedStoreChannel;
import org.neo4j.kernel.impl.transaction.log.entry.LogHeader;
import org.neo4j.kernel.lifecycle.Lifecycle;

/**
 * Main point of access to database transactional logs.
 * Provide access to low level file based operations, log file headers, {@link LogFile}
 * and {@link PhysicalLogVersionedStoreChannel}
 */
public interface LogFiles extends Lifecycle
{
    long getLogVersion( File historyLogFile );

    File[] logFiles();

    boolean isLogFile( File file );

    File logFilesDirectory();

    File getLogFileForVersion( long version );

    File getHighestLogFile();

    long getHighestLogVersion();

    long getLowestLogVersion();

    LogHeader extractHeader( long version ) throws IOException;

    PhysicalLogVersionedStoreChannel openForVersion( long version ) throws IOException;

    boolean versionExists( long version );

    boolean hasAnyEntries( long version );

    void accept( LogVersionVisitor visitor );

    void accept( LogHeaderVisitor visitor ) throws IOException;

    LogFile getLogFile();

    TransactionLogFileInformation getLogFileInformation();

    LogFileChannelNativeAccessor getChannelNativeAccessor();

    PhysicalLogVersionedStoreChannel createLogChannelForVersion( long versionUsed, LongSupplier lastCommittedTransactionId ) throws IOException;
}

==> neo4j-kernel-4.4.45-sources.jar: org/neo4j/kernel/impl/transaction/log/files/LogFiles.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.transaction.log.files;

import java.io.IOException;
import java.nio.file.Path;

import org.neo4j.kernel.impl.transaction.log.PhysicalLogVersionedStoreChannel;
import org.neo4j.kernel.impl.transaction.log.files.checkpoint.CheckpointFile;
import org.neo4j.kernel.lifecycle.Lifecycle;

/**
 * Main point of access to database transactional logs.
 * Provide access to low level file based operations, log file headers, {@link LogFile}
 * and {@link PhysicalLogVersionedStoreChannel}
 */
public interface LogFiles extends Lifecycle
{
    CheckpointFile getCheckpointFile();

    LogFile getLogFile();

    Path logFilesDirectory();

    Path[] logFiles() throws IOException;

    boolean isLogFile( Path path );

    LogTailInformation getTailInformation();
}
